@@ -2,7 +2,7 @@
 
 package Dancer::Plugin::DBIC;
 BEGIN {
-  $Dancer::Plugin::DBIC::VERSION = '0.01';
+  $Dancer::Plugin::DBIC::VERSION = '0.10';
 }
 
 use strict;
@@ -12,6 +12,7 @@ use DBIx::Class;
 use DBIx::Class::Schema::Loader qw/ make_schema_at /;
 
 my  $cfg = plugin_setting;
+my  $DBH = {};
 
 
 foreach my $keyword (keys %{ $cfg }) {
@@ -28,12 +29,21 @@ foreach my $keyword (keys %{ $cfg }) {
             $cfg->{$keyword}->{pckg},
             {},
             [ @dsn ],
-        );
+        ) unless $cfg->{skip_automake};
         
         push @dsn, $cfg->{$keyword}->{options}  if $cfg->{$keyword}->{options};
         
-        my     $package = $cfg->{$keyword}->{pckg};
-        return $package->connect(@dsn);
+        my  $variable = lc $cfg->{$keyword}->{pckg};
+            $variable =~ s/::/\-/g;
+            
+        my  $package  = $cfg->{$keyword}->{pckg};
+        
+        unless ( $Dancer::Plugin::DBIC::DBH->{$keyword}->{$variable} ) {
+            $Dancer::Plugin::DBIC::DBH->{$keyword}->{$variable} =
+            $package->connect(@dsn);
+        }
+        
+        return $Dancer::Plugin::DBIC::DBH->{$keyword}->{$variable};
     };
 }
 
@@ -49,7 +59,7 @@ Dancer::Plugin::DBIC - DBIx::Class interface for Dancer applications
 
 =head1 VERSION
 
-version 0.01
+version 0.10
 
 =head1 SYNOPSIS
 
@@ -57,7 +67,7 @@ version 0.01
     plugins:
       DBIC:
         foo:
-          pckg: "Foo-Bar"
+          pckg: "Foo::Bar"
           dsn:  "dbi:mysql:db_foo"
           user: "root"
           pass: "****"
@@ -65,6 +75,12 @@ version 0.01
             RaiseError: 1
             PrintError: 1
     
+    # Note! If your app already has a DBIC schema you may turn off auto generation like so..
+    plugins:
+      DBIC:
+        foo:
+          skip_automake: 1
+    
     # Dancer Code File
     use Dancer;
     use Dancer::Plugin::DBIC;
